@@ -61,22 +61,20 @@ class FrontEnd(object):
         start_logging(options.log_file, options.log_level, options.quiet)
 
     def get_config(self, path=None):
-        possible_config = (
-            options.config,
-            path,
-            os.path.expanduser('~/.tvrenamr/config.yml'),
-            os.path.join(sys.path[0], 'config.yml')
-        )
+        """Get the first viable config from the list of possiblities"""
+        def exists(x):
+            return x is not None and os.path.exists(x)
 
-        # get the first viable config from the list of possibles
-        _config = None
-        for config in possible_config:
-            if config is not None and os.path.exists(config):
-                _config = Config(config)
-                break
-        if _config is None:
-            raise ConfigNotFoundException
-        self.config = _config
+        possible_configs = iter(filter(exists, (
+            os.path.join(sys.path[0], 'config.yml'),
+            os.path.expanduser('~/.tvrenamr/config.yml'),
+            path,
+            options.config,
+        )))
+
+        location = next(possible_configs, None)
+
+        self.config = Config(location)
 
     def rename(self, path):
         working, filename = os.path.split(path)
@@ -103,8 +101,7 @@ class FrontEnd(object):
             tv.rename(filename, path)
         except KeyboardInterrupt:
             sys.exit()
-        except (ConfigNotFoundException,
-                NoMoreLibrariesException,
+        except (NoMoreLibrariesException,
                 NoNetworkConnectionException):
             if options.dry or options.debug:
                 self._stop_dry_run()
