@@ -2,6 +2,7 @@ from __future__ import unicode_literals
 import logging
 import os
 import re
+import shutil
 
 from . import errors
 from .libraries import TheTvDb, TvRage
@@ -205,7 +206,9 @@ class TvRenamr(object):
         if canonical:
             episode._file.show_name = canonical
         else:
-            episode._file.show_name = self.config.get_canonical(episode._file.show_name)
+            episode._file.show_name = self.config.get(episode._file.show_name,
+                                                      'canonical',
+                                                      episode._file.show_name)
         log.debug('Show Name: {0}'.format(episode._file.show_name))
 
         # loop the libraries until one works
@@ -263,9 +266,7 @@ class TvRenamr(object):
 
         """
         if rename_dir is None:
-            rename_dir = self.config.get(_file.show_name, 'renamed')
-        if rename_dir is False:
-            rename_dir = self.working_dir
+            rename_dir = self.config.get(_file.show_name, 'renamed', self.working_dir)
 
         if organise is None:
             organise = self.config.get(_file.show_name, 'organise')
@@ -295,7 +296,7 @@ class TvRenamr(object):
         log.debug(destination_filepath)
         if not self.dry and not self.debug:
             source_filepath = os.path.join(self.working_dir, current_filepath)
-            os.rename(source_filepath, destination_filepath)
+            shutil.move(source_filepath, destination_filepath)
         destination_file = os.path.split(destination_filepath)[1]
         log.log(26, 'Renamed: "{0}"'.format(destination_file))
         return destination_filepath
